"""Add indices for the `latest_event_time` column in the `conversation` table.

Reason:
The Conversations screen progressively loads items from most to
least recent. This speeds up that operation for large data sets.

Revision ID: 17e6230c5f40
Revises: 473b15141809

"""
from alembic import op
import rasax.community.database.schema_migrations.alembic.utils as migration_utils
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = "17e6230c5f40"
down_revision = "3d91317b7460"
branch_labels = None
depends_on = None

TABLE_NAME = "conversation"
LATEST_EVENT_TIME_ASC_INDEX_NAME = "latest_event_time_idx_asc"
LATEST_EVENT_TIME_DESC_INDEX_NAME = "latest_event_time_idx_desc"


def upgrade() -> None:
    if not migration_utils.index_exists(TABLE_NAME, LATEST_EVENT_TIME_ASC_INDEX_NAME):
        with op.batch_alter_table(TABLE_NAME) as batch_op:
            batch_op.create_index(
                LATEST_EVENT_TIME_ASC_INDEX_NAME, [sa.text("latest_event_time ASC")]
            )

    if not migration_utils.index_exists(TABLE_NAME, LATEST_EVENT_TIME_DESC_INDEX_NAME):
        with op.batch_alter_table(TABLE_NAME) as batch_op:
            batch_op.create_index(
                LATEST_EVENT_TIME_DESC_INDEX_NAME, [sa.text("latest_event_time DESC")]
            )


def downgrade() -> None:
    for index_name in [
        LATEST_EVENT_TIME_ASC_INDEX_NAME,
        LATEST_EVENT_TIME_DESC_INDEX_NAME,
    ]:
        if migration_utils.index_exists(index_name, TABLE_NAME):
            with op.batch_alter_table(TABLE_NAME) as batch_op:
                batch_op.drop_index(index_name)
